/*************************************************************************
TuXBuZZ - bY DoC#include
requests.h 
**************************************************************************/

#ifndef REQUESTS_H
#define REQUESTS_H

#include <stdio.h>
#include <sys/types.h>
#include <sys/socket.h>
#ifdef LINUX
  #include <resolv.h> /* exclusivo do linux */
#endif
#include <sys/stat.h>
#include <fcntl.h>
#include <unistd.h>
#include <sys/utsname.h> /* para uname */
#include <string.h> 
#include <pwd.h>


#include "tuxbuzzpackage.h"
#include "messages.h"							
              
int parse_requests(struct TuxbuzzPackage pack,int clientsock);
int process_request_info(int clientsock,int flags);
int process_request_get(int clientsock);
int process_request_disconnect(int clientsock);
int process_request_ls(int clientsock); 
int process_request_cd(int clientsock,struct TuxbuzzPackage tpack);
int process_request_pwd(int clientsock);
            
#endif

/* fim de requests.h */
